private repo: As seguintes assinaturas eram inválidas

1

Em meus 'clientes' biônicos, recebo:

GPG error: http://repo.localpod/Dml/ldom-debs/ubuntu bionic InRelease: The following signatures were invalid: ADE541A20ACF8997C01BDCF7090678A30132048A

Note que diz "inválido", não faltando!

Estes são meus próprios pacotes .deb, coletados em um repositório.  (isso funciona bem para o trusty & xenial)

Eu assinei o repo com algo como: (chamado via reprepro: conf / distributions)

gpg --batch --yes --keyring $KeyP --secret-keyring $KeyS -a --no-permission-warning   --detach-sign --default-key 'ldom install service' --output $3 $1
$1 = .../Release
$2 = .../InRelease

ok, então eu tentei:

 wget  http://repo.localpod/Dml/ldom-debs/ubuntu/dists/bionic/InRelease
 and: 
 # gpgv --keyring /etc/apt/trusted.gpg "InRelease"
 gpgv: Signature made Thu 24 May 2018 12:20:29 PM CEST
 gpgv:                using DSA key 090678A30132048A
 gpgv: Good signature from "ldom install service <[email protected]>"

Isso não é, mais ou menos, como o apt-get verifica assinaturas? Ou a chave é muito antiga? tipo errado?

erro completo:

 apt-key list
 pub   rsa2048 2014-06-24 [SC]
      754A 1A7A E731 F165 D5E6  D4BD 0E08 A149 DE57 BFBE
uid           [ unknown] SaltStack Packaging Team <[email protected]>
sub   rsa2048 2014-06-24 [E]

pub   dsa1024 2013-06-10 [SCA]
      ADE5 41A2 0ACF 8997 C01B  DCF7 0906 78A3 0132 048A
uid           [ unknown] LDOM install service <[email protected]>
sub   elg1024 2013-06-10 [E]

root@ubu18:~# apt-get update
 Get:1 http://repo.localpod/Dml/ldom-debs/ubuntu bionic InRelease [1,154 B]
 Err:1 http://repo.localpod/Dml/ldom-debs/ubuntu bionic InRelease
   The following signatures were invalid:  ADE541A20ACF8997C01BDCF7090678A30132048A
 Reading package lists... Done
 W: GPG error: http://repo.localpod/Dml/ldom-debs/ubuntu bionic InRelease: The  following signatures were invalid: ADE541A20ACF8997C01BDCF7090678A30132048A
 E: The repository 'http://repo.localpod/Dml/ldom-debs/ubuntu bionic InRelease'  is not signed.
 N: Updating from such a repository can't be done securely, and is therefore disabled by default.
 N: See apt-secure(8) manpage for repository creation and user configuration details.

Qualquer pista sobre o que estou perdendo seria bem vinda ... Obrigado,

/ holger

solução alternativa:

Acabei seguindo um guia ( link ) ---- > mais ou menos. --- > ainda um pouco 'trabalho em progresso', mas aqui estão algumas dicas:

usando uma imagem docker (fresca):

docker run -it -v /your/packages:/debs ubuntu:18.04
apt update
apt install -y vim inetutils-ping curl wget netcat telnet aptitude man manpages bash-completion rng-tools reprepro iproute2

rebuild your packages:

cd  /debs/src
ls -d */DEBIAN  | xargs -n1 dirname | xargs -n1 dpkg-deb -vD --build

tempo para coisas importantes. para usar uma chave existente:

    gpg --import /debs/.../secring.gpg

para uma nova chave:

gpg --full-generate-key
#rsa 4
#bits  4096
#your_key_name
#passphrase

#
gpg --edit-key your_key_name
#addkey
#(4) RSA (sign only)
#4096
#0
#yes
#yes
#save

gpg --list-secret
gpg --list-key


gpg --export .....your..key.....number............... > keyfile
apt-key add keyfile

ok, hora da configuração do reprepro:

mkdir /debs/u18repo
cd /debs/u18repo
cat <<END >conf/options
ask-passphrase
END

cat <<END >conf/distributions
Codename: bionic
Components: main
Architectures: amd64
SignWith: .....your..key.....number...............
END
reprepro -b /debs/u18repo includedeb bionic /debs/src/*.deb

gpg --export .....your..key.....number............... > keyfile

para testar:

apt-key add keyfile
echo "deb file:////debs/u18repo/ bionic main" >> "/etc/apt/sources.list"
apt update

agora, se você compartilhar / debs / u18repo em seus clientes (httpd), e importe a chave com: apt-key add http: /.../ keyfile     atualização do apt deve funcionar ...

    
por Holger Morgen 24.05.2018 / 11:55

1 resposta

0

Eu tive o mesmo problema. No arquivo InRelease, há uma mensagem assinada em PGP e deve conter:

-----BEGIN PGP SIGNED MESSAGE-----
Hash: SHA256

Isso significa que o SHA256 é usado para assinatura. SHA1 é um algoritmo fraco e não deve ser usado. Então, se o SHA1 está lá, você precisa atualizar sua configuração do gnupg para usar o sha256 No meu caso:

echo "personal-digest-preferences SHA256 SHA384 SHA512 SHA224 RIPEMD160" >> ~/.gnupg/gpg.conf

e, em seguida, renuncie ao arquivo InRelease usando o gpg como de costume.

    
por Rasul Osmanov 09.10.2018 / 10:16